@@ -16,6 +16,9 @@ import os
 import pygame as pg
 import pygame.midi
 
+# black and white piano keys use b/w color values directly
+BACKGROUNDCOLOR = "slategray"
+
 
 def print_device_info():
     pygame.midi.init()
@@ -42,9 +45,6 @@ def _print_device_info():
 
 def input_main(device_id=None):
     pg.init()
-    pg.fastevent.init()
-    event_get = pg.fastevent.get
-    event_post = pg.fastevent.post
 
     pygame.midi.init()
 
@@ -55,14 +55,14 @@ def input_main(device_id=None):
     else:
         input_id = device_id
 
-    print("using input_id :%s:" % input_id)
+    print(f"using input_id :{input_id}:")
     i = pygame.midi.Input(input_id)
 
     pg.display.set_mode((1, 1))
 
     going = True
     while going:
-        events = event_get()
+        events = pygame.event.get()
         for e in events:
             if e.type in [pg.QUIT]:
                 going = False
@@ -77,7 +77,7 @@ def input_main(device_id=None):
             midi_evs = pygame.midi.midis2events(midi_events, i.device_id)
 
             for m_e in midi_evs:
-                event_post(m_e)
+                pygame.event.post(m_e)
 
     del i
     pygame.midi.quit()
@@ -133,8 +133,6 @@ def output_main(device_id=None):
     start_note = 53  # F3 (white key note), start_note != 0
     n_notes = 24  # Two octaves (14 white keys)
 
-    bg_color = pg.Color("slategray")
-
     key_mapping = make_key_mapping(
         [
             pg.K_TAB,
@@ -175,7 +173,7 @@ def output_main(device_id=None):
     else:
         port = device_id
 
-    print("using output_id :%s:" % port)
+    print(f"using output_id :{port}:")
 
     midi_out = pygame.midi.Output(port, 0)
     try:
@@ -183,11 +181,11 @@ def output_main(device_id=None):
         keyboard = Keyboard(start_note, n_notes)
 
         screen = pg.display.set_mode(keyboard.rect.size)
-        screen.fill(bg_color)
+        screen.fill(BACKGROUNDCOLOR)
         pg.display.flip()
 
         background = pg.Surface(screen.get_size())
-        background.fill(bg_color)
+        background.fill(BACKGROUNDCOLOR)
         dirty_rects = []
         keyboard.draw(screen, background, dirty_rects)
         pg.display.update(dirty_rects)
@@ -198,7 +196,7 @@ def output_main(device_id=None):
         pg.event.set_blocked(pg.MOUSEMOTION)
         mouse_note = 0
         on_notes = set()
-        while 1:
+        while True:
             e = pg.event.wait()
             if e.type == pg.MOUSEBUTTONDOWN:
                 mouse_note, velocity, __, __ = regions.get_at(e.pos)
@@ -247,16 +245,15 @@ def output_main(device_id=None):
         pygame.midi.quit()
 
 
-def make_key_mapping(key_list, start_note):
+def make_key_mapping(keys, start_note):
     """Return a dictionary of (note, velocity) by computer keyboard key code"""
-
     mapping = {}
-    for i in range(len(key_list)):
-        mapping[key_list[i]] = (start_note + i, 127)
+    for i, key in enumerate(keys):
+        mapping[key] = (start_note + i, 127)
     return mapping
 
 
-class NullKey(object):
+class NullKey:
     """A dummy key that ignores events passed to it by other keys
 
     A NullKey instance is the left key instance used by default
@@ -345,8 +342,8 @@ def key_class(updates, image_strip, image_rects, is_white_key=True):
         key_color = "white"
     else:
         key_color = "black"
-    c_notify_down_method = "_right_%s_down" % key_color
-    c_notify_up_method = "_right_%s_up" % key_color
+    c_notify_down_method = f"_right_{key_color}_down"
+    c_notify_up_method = f"_right_{key_color}_up"
 
     # Images:
     #
@@ -427,7 +424,7 @@ def key_class(updates, image_strip, image_rects, is_white_key=True):
         )
         c_event_right_black_up[down_state_all] = (down_state_self_white, image_rects[2])
 
-    class Key(object):
+    class Key:
         """A key widget, maintains key state and draws the key's image
 
         Constructor arguments:
@@ -624,7 +621,7 @@ def key_images():
     return strip, rects
 
 
-class Keyboard(object):
+class Keyboard:
     """Musical keyboard widget
 
     Constructor arguments:
@@ -706,7 +703,7 @@ class Keyboard(object):
         """
 
         # Keys are entered in a list, where index is Midi note. Since there are
-        # only 128 possible Midi notes the list length is managable. Unassigned
+        # only 128 possible Midi notes the list length is manageable. Unassigned
         # note positions should never be accessed, so are set None to ensure
         # the bug is quickly detected.
         #
@@ -856,18 +853,16 @@ def main(mode="output", device_id=None):
     elif mode == "list":
         print_device_info()
     else:
-        raise ValueError("Unknown mode option '%s'" % mode)
+        raise ValueError(f"Unknown mode option '{mode}'")
 
 
 if __name__ == "__main__":
-
     try:
         device_id = int(sys.argv[-1])
     except ValueError:
         device_id = None
 
     if "--input" in sys.argv or "-i" in sys.argv:
-
         input_main(device_id)
 
     elif "--output" in sys.argv or "-o" in sys.argv:
@@ -876,3 +871,5 @@ if __name__ == "__main__":
         print_device_info()
     else:
         usage()
+
+    pg.quit()
