@@ -1,13 +1,12 @@
-import unittest
 import math
 import operator
 import platform
+import unittest
+from collections.abc import Collection, Sequence
 
 import pygame
-from pygame.compat import long_
 from pygame.colordict import THECOLORS
 
-
 IS_PYPY = "PyPy" == platform.python_implementation()
 ################################### CONSTANTS ##################################
 
@@ -205,7 +204,7 @@ class ColorTypeTest(unittest.TestCase):
         self.assertTrue([255, 0, 0, 0] != Color(255, 0, 0, 0))
 
         # Comparison is not implemented for invalid color values.
-        class Test(object):
+        class Test:
             def __eq__(self, other):
                 return -1
 
@@ -269,6 +268,12 @@ class ColorTypeTest(unittest.TestCase):
         r, g, b = c
         self.assertEqual((1, 2, 3), (r, g, b))
 
+        # Checking if DeprecationWarning is triggered
+        # when function is called
+        for i in range(1, 5):
+            with self.assertWarns(DeprecationWarning):
+                c.set_length(i)
+
     def test_length(self):
         # should be able to unpack to r,g,b,a and r,g,b
         c = pygame.Color(1, 2, 3, 4)
@@ -290,7 +295,7 @@ class ColorTypeTest(unittest.TestCase):
         self.assertRaises(ValueError, c.set_length, 5)
         self.assertRaises(ValueError, c.set_length, -1)
         self.assertRaises(ValueError, c.set_length, 0)
-        self.assertRaises(ValueError, c.set_length, pow(2, long_(33)))
+        self.assertRaises(ValueError, c.set_length, pow(2, 33))
 
     def test_case_insensitivity_of_string_args(self):
         self.assertEqual(pygame.color.Color("red"), pygame.color.Color("Red"))
@@ -400,8 +405,7 @@ class ColorTypeTest(unittest.TestCase):
             self.assertEqual(color.a, value & 0xFF)
 
     def test_color__int_arg_invalid(self):
-        """Ensures invalid int values are detected when creating Color objects.
-        """
+        """Ensures invalid int values are detected when creating Color objects."""
         with self.assertRaises(ValueError):
             color = pygame.Color(0x1FFFFFFFF)
 
@@ -430,8 +434,7 @@ class ColorTypeTest(unittest.TestCase):
             self.assertEqual(color.a, 255)
 
     def test_color__sequence_arg_invalid_value(self):
-        """Ensures invalid sequences are detected when creating Color objects.
-        """
+        """Ensures invalid sequences are detected when creating Color objects."""
         cls = pygame.Color
         for seq_type in (tuple, list):
             self.assertRaises(ValueError, cls, seq_type((256, 90, 80, 70)))
@@ -761,7 +764,7 @@ class ColorTypeTest(unittest.TestCase):
         self.assertEqual(c.g, 0)
         self.assertEqual(c.b, 204)
         self.assertEqual(c.a, 0)
-        self.assertEqual(long_(c), long_(0xCC00CC00))
+        self.assertEqual(int(c), int(0xCC00CC00))
 
         # This will be an int
         c = pygame.Color(0x33727592)
@@ -769,7 +772,7 @@ class ColorTypeTest(unittest.TestCase):
         self.assertEqual(c.g, 114)
         self.assertEqual(c.b, 117)
         self.assertEqual(c.a, 146)
-        self.assertEqual(long_(c), long_(0x33727592))
+        self.assertEqual(int(c), int(0x33727592))
 
     def test_normalize(self):
         c = pygame.Color(204, 38, 194, 55)
@@ -868,14 +871,14 @@ class ColorTypeTest(unittest.TestCase):
     def test_issue_269(self):
         """PyColor OverflowError on HSVA with hue value of 360
 
-           >>> c = pygame.Color(0)
-           >>> c.hsva = (360,0,0,0)
-           Traceback (most recent call last):
-             File "<stdin>", line 1, in <module>
-           OverflowError: this is not allowed to happen ever
-           >>> pygame.ver
-           '1.9.1release'
-           >>>
+        >>> c = pygame.Color(0)
+        >>> c.hsva = (360,0,0,0)
+        Traceback (most recent call last):
+          File "<stdin>", line 1, in <module>
+        OverflowError: this is not allowed to happen ever
+        >>> pygame.ver
+        '1.9.1release'
+        >>>
 
         """
 
@@ -988,7 +991,6 @@ class ColorTypeTest(unittest.TestCase):
 
     @unittest.skipIf(IS_PYPY, "PyPy has no ctypes")
     def test_arraystruct(self):
-
         import pygame.tests.test_utils.arrinter as ai
         import ctypes as ct
 
@@ -1016,23 +1018,20 @@ class ColorTypeTest(unittest.TestCase):
 
         class ColorImporter(buftools.Importer):
             def __init__(self, color, flags):
-                super(ColorImporter, self).__init__(color, flags)
+                super().__init__(color, flags)
                 self.items = cast(self.buf, POINTER(c_uint8))
 
             def __getitem__(self, index):
                 if 0 <= index < 4:
                     return self.items[index]
-                raise IndexError(
-                    "valid index values are between 0 and 3: " "got {}".format(index)
-                )
+                raise IndexError(f"valid index values are between 0 and 3: got {index}")
 
             def __setitem__(self, index, value):
                 if 0 <= index < 4:
                     self.items[index] = value
                 else:
                     raise IndexError(
-                        "valid index values are between 0 and 3: "
-                        "got {}".format(index)
+                        f"valid index values are between 0 and 3: got {index}"
                     )
 
         c = pygame.Color(50, 100, 150, 200)
@@ -1090,6 +1089,52 @@ class ColorTypeTest(unittest.TestCase):
             self.assertEqual(imp.shape, (i,))
         self.assertRaises(BufferError, ColorImporter, c, buftools.PyBUF_WRITABLE)
 
+    def test_color_iter(self):
+        c = pygame.Color(50, 100, 150, 200)
+
+        # call __iter__ explicitly to test that it is defined
+        color_iterator = c.__iter__()
+        for i, val in enumerate(color_iterator):
+            self.assertEqual(c[i], val)
+
+    def test_color_contains(self):
+        c = pygame.Color(50, 60, 70)
+
+        # call __contains__ explicitly to test that it is defined
+        self.assertTrue(c.__contains__(50))
+        self.assertTrue(60 in c)
+        self.assertTrue(70 in c)
+        self.assertFalse(100 in c)
+        self.assertFalse(c.__contains__(10))
+
+        self.assertRaises(TypeError, lambda: "string" in c)
+        self.assertRaises(TypeError, lambda: 3.14159 in c)
+
+    def test_grayscale(self):
+        Color = pygame.color.Color
+
+        color = Color(255, 0, 0, 255)
+        self.assertEqual(color.grayscale(), Color(76, 76, 76, 255))
+        color = Color(3, 5, 7, 255)
+        self.assertEqual(color.grayscale(), Color(4, 4, 4, 255))
+        color = Color(3, 5, 70, 255)
+        self.assertEqual(color.grayscale(), Color(11, 11, 11, 255))
+        color = Color(3, 50, 70, 255)
+        self.assertEqual(color.grayscale(), Color(38, 38, 38, 255))
+        color = Color(30, 50, 70, 255)
+        self.assertEqual(color.grayscale(), Color(46, 46, 46, 255))
+
+        color = Color(255, 0, 0, 144)
+        self.assertEqual(color.grayscale(), Color(76, 76, 76, 144))
+        color = Color(3, 5, 7, 144)
+        self.assertEqual(color.grayscale(), Color(4, 4, 4, 144))
+        color = Color(3, 5, 70, 144)
+        self.assertEqual(color.grayscale(), Color(11, 11, 11, 144))
+        color = Color(3, 50, 70, 144)
+        self.assertEqual(color.grayscale(), Color(38, 38, 38, 144))
+        color = Color(30, 50, 70, 144)
+        self.assertEqual(color.grayscale(), Color(46, 46, 46, 144))
+
     def test_lerp(self):
         # setup
         Color = pygame.color.Color
@@ -1153,20 +1198,84 @@ class ColorTypeTest(unittest.TestCase):
         self.assertEqual(alpha255.premul_alpha(), Color(128, 128, 128, 255))
 
         # full range of alpha auto sub-testing
-        test_colors = [(200, 30, 74), (76, 83, 24), (184, 21, 6),
-                       (74, 4, 74), (76, 83, 24), (184, 21, 234),
-                       (160, 30, 74), (96, 147, 204), (198, 201, 60),
-                       (132, 89, 74), (245, 9, 224), (184, 112, 6)]
+        test_colors = [
+            (200, 30, 74),
+            (76, 83, 24),
+            (184, 21, 6),
+            (74, 4, 74),
+            (76, 83, 24),
+            (184, 21, 234),
+            (160, 30, 74),
+            (96, 147, 204),
+            (198, 201, 60),
+            (132, 89, 74),
+            (245, 9, 224),
+            (184, 112, 6),
+        ]
 
         for r, g, b in test_colors:
             for a in range(255):
                 with self.subTest(r=r, g=g, b=b, a=a):
-                    alpha = a/255.0
-                    self.assertEqual(Color(r, g, b, a).premul_alpha(),
-                                     Color(((r + 1) * a) >> 8,
-                                           ((g + 1) * a) >> 8,
-                                           ((b + 1) * a) >> 8,
-                                           a))
+                    alpha = a / 255.0
+                    self.assertEqual(
+                        Color(r, g, b, a).premul_alpha(),
+                        Color(
+                            ((r + 1) * a) >> 8,
+                            ((g + 1) * a) >> 8,
+                            ((b + 1) * a) >> 8,
+                            a,
+                        ),
+                    )
+
+    def test_update(self):
+        c = pygame.color.Color(0, 0, 0)
+        c.update(1, 2, 3, 4)
+
+        self.assertEqual(c.r, 1)
+        self.assertEqual(c.g, 2)
+        self.assertEqual(c.b, 3)
+        self.assertEqual(c.a, 4)
+
+        c = pygame.color.Color(0, 0, 0)
+        c.update([1, 2, 3, 4])
+
+        self.assertEqual(c.r, 1)
+        self.assertEqual(c.g, 2)
+        self.assertEqual(c.b, 3)
+        self.assertEqual(c.a, 4)
+
+        c = pygame.color.Color(0, 0, 0)
+        c2 = pygame.color.Color(1, 2, 3, 4)
+        c.update(c2)
+
+        self.assertEqual(c.r, 1)
+        self.assertEqual(c.g, 2)
+        self.assertEqual(c.b, 3)
+        self.assertEqual(c.a, 4)
+
+        c = pygame.color.Color(1, 1, 1)
+        c.update("black")
+
+        self.assertEqual(c.r, 0)
+        self.assertEqual(c.g, 0)
+        self.assertEqual(c.b, 0)
+        self.assertEqual(c.a, 255)
+
+        c = pygame.color.Color(0, 0, 0, 120)
+        c.set_length(3)
+        c.update(1, 2, 3)
+        self.assertEqual(len(c), 3)
+        c.set_length(4)
+        self.assertEqual(c[3], 120)
+
+        c.set_length(3)
+        c.update(1, 2, 3, 4)
+        self.assertEqual(len(c), 4)
+
+    def test_collection_abc(self):
+        c = pygame.Color(64, 70, 75, 255)
+        self.assertTrue(isinstance(c, Collection))
+        self.assertFalse(isinstance(c, Sequence))
 
 
 class SubclassTest(unittest.TestCase):
@@ -1239,6 +1348,11 @@ class SubclassTest(unittest.TestCase):
         self.assertTrue(isinstance(mc2, self.MyColor))
         self.assertRaises(AttributeError, getattr, mc2, "an_attribute")
 
+    def test_collection_abc(self):
+        mc1 = self.MyColor(64, 70, 75, 255)
+        self.assertTrue(isinstance(mc1, Collection))
+        self.assertFalse(isinstance(mc1, Sequence))
+
 
 ################################################################################
 
