@@ -277,6 +277,9 @@ class FontTypeTest(unittest.TestCase):
     def tearDown(self):
         pygame_font.quit()
 
+    def test_default_parameters(self):
+        f = pygame_font.Font()
+
     def test_get_ascent(self):
         # Ckecking ascent would need a custom test font to do properly.
         f = pygame_font.Font(None, 20)
@@ -516,12 +519,27 @@ class FontTypeTest(unittest.TestCase):
         )
         f = pygame_font.Font(font_path, 20)
 
+    def test_load_from_file_default(self):
+        font_name = pygame_font.get_default_font()
+        font_path = os.path.join(
+            os.path.split(pygame.__file__)[0], pygame_font.get_default_font()
+        )
+        f = pygame_font.Font(font_path)
+
     def test_load_from_pathlib(self):
         font_name = pygame_font.get_default_font()
         font_path = os.path.join(
             os.path.split(pygame.__file__)[0], pygame_font.get_default_font()
         )
         f = pygame_font.Font(pathlib.Path(font_path), 20)
+        f = pygame_font.Font(pathlib.Path(font_path))
+
+    def test_load_from_pathlib_default(self):
+        font_name = pygame_font.get_default_font()
+        font_path = os.path.join(
+            os.path.split(pygame.__file__)[0], pygame_font.get_default_font()
+        )
+        f = pygame_font.Font(pathlib.Path(font_path))
 
     def test_load_from_file_obj(self):
         font_name = pygame_font.get_default_font()
@@ -531,11 +549,24 @@ class FontTypeTest(unittest.TestCase):
         with open(font_path, "rb") as f:
             font = pygame_font.Font(f, 20)
 
+    def test_load_from_file_obj_default(self):
+        font_name = pygame_font.get_default_font()
+        font_path = os.path.join(
+            os.path.split(pygame.__file__)[0], pygame_font.get_default_font()
+        )
+        with open(font_path, "rb") as f:
+            font = pygame_font.Font(f)
+
     def test_load_default_font_filename(self):
         # In font_init, a special case is when the filename argument is
         # identical to the default font file name.
         f = pygame_font.Font(pygame_font.get_default_font(), 20)
 
+    def test_load_default_font_filename_default(self):
+        # In font_init, a special case is when the filename argument is
+        # identical to the default font file name.
+        f = pygame_font.Font(pygame_font.get_default_font())
+
     def _load_unicode(self, path):
         import shutil
 
@@ -582,10 +613,31 @@ class FontTypeTest(unittest.TestCase):
             font = pygame_font.Font(fpath, size)
             font.render("WHERE", True, "black")
 
+    def test_font_set_script(self):
+        if pygame_font.__name__ == "pygame.ftfont":
+            return  # this ain't a pygame.ftfont thing!
+
+        font = pygame_font.Font(None, 16)
+
+        ttf_version = pygame_font.get_sdl_ttf_version()
+        if ttf_version >= (2, 20, 0):
+            self.assertRaises(TypeError, pygame.font.Font.set_script)
+            self.assertRaises(TypeError, pygame.font.Font.set_script, font)
+            self.assertRaises(TypeError, pygame.font.Font.set_script, "hey", "Deva")
+            self.assertRaises(TypeError, font.set_script, 1)
+            self.assertRaises(TypeError, font.set_script, ["D", "e", "v", "a"])
+
+            self.assertRaises(ValueError, font.set_script, "too long by far")
+            self.assertRaises(ValueError, font.set_script, "")
+            self.assertRaises(ValueError, font.set_script, "a")
+
+            font.set_script("Deva")
+        else:
+            self.assertRaises(pygame.error, font.set_script, "Deva")
+
 
 @unittest.skipIf(IS_PYPY, "pypy skip known failure")  # TODO
 class VisualTests(unittest.TestCase):
-
     __tags__ = ["interactive"]
 
     screen = None
